#!/bin/bash

VERSION='20190508t114341'
OTHER_ACCOUNT='jopsen@gmail.com'


export PUB_HOSTED_URL="https://$VERSION-dot-dartlang-pub.appspot.com"

# Bump VERSION
expr 1 + `cat VERSION` > VERSION
cat pubspec.yaml.in | sed -e "s/PKGVERSION/`cat VERSION`/g" > pubspec.yaml

echo '### pub get'
rm -rf .packages pubspec.lock
pub get;
if [ $? -ne 0 ]; then
  echo 'FAILURE: Unable to pub get';
  exit 1;
else
  echo 'SUCCESS';
fi

echo '### pub upgrade'
pub upgrade;
if [ $? -ne 0 ]; then
  echo 'FAILURE: Unable to pub upgrade';
  exit 1;
else
  echo 'SUCCESS';
fi

echo '### pub publish'
pub publish;
if [ $? -ne 0 ]; then
  echo 'FAILURE: Unable to pub publish';
  exit 1;
else
  echo 'SUCCESS';
fi

# Create clean PUB_CACHE
(
export PUB_CACHE=`mktemp -d`

echo '### pub get example/ (clean PUB_CACHE)'
rm -f example/pubspec.lock example/.packages
cd example/ && pub get
if [ $? -ne 0 ]; then
  echo 'FAILURE: Unable to get package we just published';
  exit 1;
else
  echo 'SUCCESS';
fi

echo '### test example/ runs'
dart bin/main.dart
if [ $? -ne 0 ]; then
  echo 'FAILURE: Unable to run example/bin/main.dart';
  exit 1;
else
  echo 'SUCCESS';
fi

# Restore PUB_CACHE
rm -rf "$PUB_CACHE"
)

echo '### Check availability on pub.dev'
curl -sL "$PUB_HOSTED_URL/packages/_dummy_pkg" | grep "0.0.`cat VERSION`" > /dev/null
if [ $? -ne 0 ]; then
  echo 'FAILURE: Public website does not have the package!';
  exit 1;
else
  echo 'SUCCESS';
fi

echo '### Remove uploader, if OTHER_ACCOUNT is already an uploader'
curl -sL "$PUB_HOSTED_URL/packages/_dummy_pkg.json" | grep "$OTHER_ACCOUNT" > /dev/null
if [ $? -eq 0 ]; then
  pub uploader remove "$OTHER_ACCOUNT"
fi

echo '### Add uploader'
pub uploader add "$OTHER_ACCOUNT"
if [ $? -ne 0 ]; then
  echo 'FAILURE: pub uploader add $OTHER_ACCOUNT failed!';
  exit 1;
fi

echo "### Please accept invite sent to $OTHER_ACCOUNT, hit enter when done"
read VAR

echo '### Check that OTHER_ACCOUNT is uploader'
curl -sL "$PUB_HOSTED_URL/packages/_dummy_pkg.json" | grep "$OTHER_ACCOUNT" > /dev/null
if [ $? -ne 0 ]; then
  echo 'FAILURE: OTHER_ACCOUNT is not uploader';
  exit 1;
else
  echo 'SUCCESS';
fi

echo '### Remove uploader'
pub uploader remove "$OTHER_ACCOUNT"
if [ $? -ne 0 ]; then
  echo 'FAILURE: pub uploader remove $OTHER_ACCOUNT failed!';
  exit 1;
fi

echo '### Check that OTHER_ACCOUNT is NOT uploader'
curl -sL "$PUB_HOSTED_URL/packages/_dummy_pkg.json" | grep "$OTHER_ACCOUNT" > /dev/null
if [ $? -ne 0 ]; then
  echo 'SUCCESS';
else
  echo 'FAILURE: OTHER_ACCOUNT is still an uploader!';
  exit 1;
fi